cgexplore.systems\_optimisation.define\_pyramid\_angle
======================================================

.. currentmodule:: cgexplore.systems_optimisation

.. autofunction:: define_pyramid_angle